@@ -7,21 +7,10 @@ use Mouse::Util::TypeConstraints;
 use parent qw{Elive};
 
 use Scalar::Util;
+use Elive::Util;
 
 __PACKAGE__->mk_classdata('element_class');
-__PACKAGE__->mk_classdata('separator' => ';');
-
-coerce 'Elive::Array' => from 'Str'
-          => via {
-	      my $a = [ split(__PACKAGE__->separator) ];
-	      bless ($a, __PACKAGE__);
-          };
-
-coerce 'Elive::Array' => from 'ArrayRef'
-          => via {
-	      my @a = map {Elive::Util::string($_)} @$_;
-	      bless (\@a, __PACKAGE__);
-          };
+__PACKAGE__->mk_classdata('separator' => ',');
 
 =head1 NAME
 
@@ -38,21 +27,47 @@ Elive::Entity::participantList.
 
 =cut
 
+sub _build_array {
+    my $class = shift;
+    my $spec = shift;
+
+    my $type = Elive::Util::_reftype( $spec );
+    $spec = [$spec] if ($type && $type ne 'ARRAY');
+
+    my @args;
+
+    if ($type) {
+	@args = map {Elive::Util::string($_)} @$spec;
+    }
+    else {
+	@args = split($class->separator, Elive::Util::string($spec));
+    }
+
+    return \@args;
+}
+
+our $class = __PACKAGE__;
+coerce $class => from 'ArrayRef|Str'
+          => via {
+	      $class->new( $_ );
+          };
+
 =head2 stringify
 
-Serialises array members by joining their string values with ';'.
+Serialises array members by joining individual elements.
 
 =cut
 
 sub stringify {
-    my $self = shift;
-    my $arr  = shift || $self;
-    my $type = shift || $self->element_class;
+    my $class = shift;
+    my $spec  = shift;
+    my $type = shift || $class->element_class;
 
-    $arr = [split($self->separator, $arr)]
-	if defined $arr && !Scalar::Util::reftype($arr);
+    $spec = $class
+	if !defined $spec && ref $class;
+    my $arr = $class->_build_array( $spec );
 
-    return join($self->separator, sort map {Elive::Util::string($_, $type)} @$arr)
+    return join($class->separator, sort map {Elive::Util::string($_, $type)} @$arr)
 }
 
 =head2 new
@@ -62,8 +77,9 @@ sub stringify {
 =cut
 
 sub new {
-    my ($class,$ref) = @_;
-    return bless($ref || [], $class);
+    my ($class, $spec) = @_;
+    my $array = $class->_build_array( $spec );
+    return bless($array, $class);
 }
 
 =head2 add 
@@ -77,9 +93,6 @@ Add elements to an array.
 sub add {
     my ($self, @elems) =  @_;
 
-    @elems = (map {Scalar::Util::reftype($_)? $_: split($self->separator)} 
-	      grep {defined} @elems);
-
     if (my $element_class = $self->element_class) {
 	foreach (@elems) {
 	    $_ = $element_class->new($_)
