@@ -634,7 +634,7 @@ L<Elive::Entity::Participant>. Each participant contains one of:
 
 =item type 1 (L<Elive::Entity::Group>), or
 
-=item type 2 (L<Elive::Entity::Invited::Guest>)
+=item type 2 (L<Elive::Entity::InvitedGuest>)
 
 =back
 
@@ -689,6 +689,20 @@ You may modify this list in any way, then update the session it belongs to:
 
 =head1 Working with Preloads
 
+There are three types of preloads:
+
+=over 4
+
+=item (1) whiteboard (file extension C<*.wbd>)
+
+=item (2) Elluminate Plan! (file extension C<*.elp>)
+
+=item (3) Multimedia (everything else)
+
+=back
+
+=head2 Creating Preloads
+
 Preloads may be both uploaded from the client or server:
 
     # 1. upload a local file
@@ -700,16 +714,40 @@ Preloads may be both uploaded from the client or server:
     my $content = do {local $/; $fh->binmode; <$fh>};
     close $fh;
 
-    my $preload2 = Elive::Entity::Preload->upload(
+    my $preload2 = Elive::Entity::Preload->upload({
                      name => 'slide2.wbd',
                      data => $content,
-                   );
+                   });
 
     # 3. import a file on the Elluminate Live! server
     my $preload3 = Elive::Entity::Preload
          ->import_from_server('/home/uploads/slide3.wbd');
 
-These can then be added to sessions in a number of ways:
+The type of the preload can be C<whiteboard>, C<media> or C<plan>. Each
+preload also has a C<mimeType> property. Both are guessed from the file
+extension, or you can supply, these yourself:
+
+    $preload2 =  Elive::Entity::Preload->upload({
+                     name => 'slide2.wbd',
+                     data => $content,
+                     type => 'preload',
+                     mimeType => 'application/octet-stream',
+                   });
+
+The C<import_from_server> method also has an extended form:
+
+    $preload2 =  Elive::Entity::Preload->import_from_server({
+                     fileName =>'/home/uploads/slide3.wbd.tmp123'
+                     data => $content,
+                     type => 'preload',
+                     mimeType => 'application/octet-stream',
+                   });
+
+Where C<fileName> is the path to the file to be uploaded.
+
+=head2 Associating Preloads with Sessions
+
+Preloads can then be added to sessions in a number of ways:
 
     # 1. at session creation
     my $session = Elive::Entity->Session->create({
@@ -728,8 +766,8 @@ A single preload can be shared between sessions:
     $session1->add_preload( $preload );
     $session2->add_preload( $preload );
 
-Attempt to add the same preload to a session more than once is considered an
-error. The C<check_preload> method might help here>
+Attempting to add the same preload to a session more than once is considered
+an error. The C<check_preload> method might help here>
 
     $session->add_preload( $preload )
         unless $session->check_preload( $preload );
@@ -794,18 +832,18 @@ Elluminate Live! web server.
 
 For more information, please see L<Elive::Entity::Recording>.
 
-=head2 Working with Recurring aSessions
+=head1 Working with Recurring Sessions
+
+=head2 Recurring Sessions - Parameters
 
 The C<create> command has a number of additional parameters that can assist
 with setting up blocks of recurring meetings:
 
-=over 4
-
-=item C<until> (HiResDate)
+=head3 until C<HiResDate>
 
 Repeat session until this date.
 
-=item C<repeatEvery> (Int)
+=head3 repeatEvery C<Int>
 
 Repeat session type:
 
@@ -823,28 +861,28 @@ Repeat session type:
 
 =back
 
-=item C<repeatSessionInterval> (Int)
+=head3 repeatSessionInterval C<Int>
 
 Repeat the session every X days|days depending of repeatEvery value.
 
-=item C<repeatSessionMonthlyInterval> (Int)
+=head3 repeatSessionMonthlyInterval C<Int>
 
 Week of the month session should be scheduled in.
 
-=item C<repeatSessionMonthlyDay> (Int)
+=head3 repeatSessionMonthlyDay C<Int>
 
 Day of the week the monthly session should be scheduled in.
 
-=item C<sundaySessionIndicator> ... C<saturdaySessionIndicator> (Bool)
+=head3 sundaySessionIndicator ... saturdaySessionIndicator C<(Bool)>
 
 For C<repeatEvery> value = 2, which days sessions should be scheduled.
 
-=item C<timeZone> (Str)
+=head3 timeZone C<Str>
 
 An optional alternate time-zone name to use for for the scheduling
 calculations (E.g. C<Australia/Melbourne>).
 
-=back
+=head2 Recurring Sessions - Example
 
 For example, the following inserts three meetings, of duration 30 minutes,
 for today (starting in 5 minutes), tomorrow and the following day:
@@ -860,17 +898,17 @@ for today (starting in 5 minutes), tomorrow and the following day:
     my $until_msec = $until->epoch . '000';
     
     my %insert_data = (
-	name => 'tests, generated by t/soap-session-recurring.t',
-	facilitatorId => Elive->login->userId,
-	password => 'sssh!',
-	privateMeeting => 1,
+	name              => 'daily scrum meeting',
+	facilitatorId     => Elive->login->userId,
+	password          => 'sssh!',
+	privateMeeting    => 1,
 	restrictedMeeting => 1,
 
 	start =>  $start_msec,
-	end => $end_msec,
-	until => $until_msec,
+	end   => $end_msec,
 
-	repeatEvery => 1,
+	until                 => $until_msec,
+	repeatEvery           => 1,
 	repeatSessionInterval => 1,
     );
 
